package com.lj.web.config;

import com.alibaba.druid.pool.DruidDataSource;

import java.io.IOException;
import java.io.InputStream;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Properties;


public class ClickHouseDruid {

    public static DruidDataSource dataSource;

    private static String driver;
    private static String urlMaster;
    private static String username;
    private static String password;
    private static int initialSize;
    private static int maxActive;
    private static int minIdle;
    private static int maxWait;
    private static String fileName = "clickhouse.properties";


    private ClickHouseDruid(){

    }

    static {
        try {
            init();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     * 加载属性文件并读取属性文件中的内容将其设置给连接信息
     * @param propName
     */
    private static void loadProp(String propName) throws IOException {
        fileName = propName;
        //属性文件位于src根目录时,加"/"则不要使用ClassLoader,如果使用ClassLoader则无需"/"
        InputStream is = SqlServerDruid.class.getClassLoader().getResourceAsStream(fileName);
        Properties p = new Properties();
        System.out.println(p == null);
        System.out.println(is == null);
        p.load(is);

        driver = p.getProperty("clickhouse.driver");
        urlMaster = p.getProperty("clickhouse.url_master");
        username = p.getProperty("clickhouse.username");
        password = p.getProperty("clickhouse.password");

        initialSize = Integer.parseInt(p.getProperty("clickhouse.initialSize"));
        maxActive = Integer.parseInt(p.getProperty("clickhouse.maxActive"));
        maxWait = Integer.parseInt(p.getProperty("clickhouse.maxWait"));
        minIdle = Integer.parseInt(p.getProperty("clickhouse.minIdle"));

    }

    public Connection clickhouseConnectionMaster() throws SQLException {
            dataSource = new DruidDataSource();
            //四个基本属性
            dataSource.setDriverClassName(driver);
            dataSource.setUrl(urlMaster);
            dataSource.setUsername(username);
            dataSource.setPassword(password);
            //其他属性
            //初始大小
            dataSource.setInitialSize(initialSize);
            //最大大小
            dataSource.setMaxActive(maxActive);
            //最小大小
            dataSource.setMinIdle(minIdle);
            //检查时间
            dataSource.setMaxWait(maxWait);
            dataSource.setMinEvictableIdleTimeMillis(60000);
            dataSource.setTimeBetweenEvictionRunsMillis(15000);

            return dataSource.getConnection();
    }

    private static void init() throws IOException {
        dataSource = new DruidDataSource();
        //加载属性文件,初始化配置
        loadProp(fileName);
        dataSource.setDriverClassName(driver);
        dataSource.setUrl(urlMaster);
        dataSource.setUsername(username);
        dataSource.setPassword(password);

        //设置连接池中初始连接数
        dataSource.setInitialSize(initialSize);
        //设置最大连接数
        dataSource.setMaxActive(maxActive);
        //设置最小的闲置链接数
        dataSource.setMinIdle(minIdle);
        //设置最大的等待时间(等待获取链接的时间)
        dataSource.setMaxWait(maxWait);
    }

    /**
     * 链接获取
     * @return
     */
    public static Connection getConn() {
        try {
            //如果连接池为空或者被异常关闭,则重新初始化一个
            System.out.println("获取来连接");
            if(dataSource == null || dataSource.isClosed()) {
                init();
            }
            return dataSource.getConnection();
        } catch (SQLException | IOException e) {
            e.printStackTrace();
        }
        return null;

    }

    /**
     * 资源关闭
     *
     * @param stmt
     * @param conn
     */
    public static void close(Statement stmt, Connection conn) {
        try {
            if (stmt != null) {
                stmt.close();
            }
            if (conn != null) {
                conn.close();
            }
        } catch (SQLException e) {
            e.printStackTrace();
        }
    }

}
